#
# spec file for package xar
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover 1
Name:           xar
Version:        1.6.1
Release:        lp152.4.6
Summary:        Extensible Archive Format Tools
License:        BSD-3-Clause
Group:          Productivity/Archiving/Compression
Url:            http://mackyle.github.com/xar
Source:         https://github.com/mackyle/xar/archive/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM ext2.patch gh#mackyle/xar#10
Patch0:         ext2.patch
Patch1:         openssl-checks.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  e2fsprogs-devel
BuildRequires:  libacl-devel
BuildRequires:  libbz2-devel
BuildRequires:  libxml2-devel
BuildRequires:  openssl-devel
BuildRequires:  zlib-devel

%description
The XAR project aims to provide an easily extensible archive format. Important
design decisions include an easily extensible XML table of contents for random
access to archived files, storing the toc at the beginning of the archive to
allow for efficient handling of streamed archives, the ability to handle files
of arbitrarily large sizes, the ability to choose independent encodings for
individual files in the archive, the ability to store checksums for individual
files in both compressed and uncompressed form, and the ability to query the
table of content's rich meta-data.

%package -n libxar%{sover}
Summary:        Extensive Archive Format Library
Group:          Development/Libraries/C and C++

%description -n libxar%{sover}
The XAR project aims to provide an easily extensible archive format. Important
design decisions include an easily extensible XML table of contents for random
access to archived files, storing the toc at the beginning of the archive to
allow for efficient handling of streamed archives, the ability to handle files
of arbitrarily large sizes, the ability to choose independent encodings for
individual files in the archive, the ability to store checksums for individual
files in both compressed and uncompressed form, and the ability to query the
table of content's rich meta-data.

%package -n libxar-devel
Summary:        Extensive Archive Format Library
Group:          Development/Libraries/C and C++
Requires:       libxar%{sover} = %{version}

%description -n libxar-devel
The XAR project aims to provide an easily extensible archive format. Important
design decisions include an easily extensible XML table of contents for random
access to archived files, storing the toc at the beginning of the archive to
allow for efficient handling of streamed archives, the ability to handle files
of arbitrarily large sizes, the ability to choose independent encodings for
individual files in the archive, the ability to store checksums for individual
files in both compressed and uncompressed form, and the ability to query the
table of content's rich meta-data.

%prep
%setup -q -n %{name}-%{name}-%{version}
%patch0
%patch1 -p1
%build
pushd xar
./autogen.sh --noconfigure
%configure --disable-static
make %{?_smp_mflags}
popd

%install
pushd xar
%make_install
popd
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libxar%{sover} -p /sbin/ldconfig
%postun -n libxar%{sover} -p /sbin/ldconfig

%files
%doc xar/ChangeLog xar/LICENSE xar/NEWS
%{_bindir}/xar
%{_mandir}/man1/xar.1%{ext_man}

%files -n libxar%{sover}
%doc xar/ChangeLog xar/LICENSE xar/NEWS
%{_libdir}/libxar.so.%{sover}

%files -n libxar-devel
%doc xar/ChangeLog xar/LICENSE xar/NEWS
%{_includedir}/xar
%{_libdir}/libxar.so

%changelog
* Tue Mar  6 2018 crrodriguez@opensuse.org
- fix build with openssl 1.1, just another broken configure test
  (openssl-checks.patch )
* Mon Dec  4 2017 mpluskal@suse.com
- Explicitly BuildRequire libopenssl-1_0_0-devel until OpenSSL
  1.1.x support is ported
- Clean up with spec-cleaner
* Mon Oct  3 2016 mpluskal@suse.com
- Add ext2.patch from voidlinux
* Fri Jul 22 2016 jengelh@inai.de
- Disable static build from the get-go if its files get removed
  anyway
* Fri Jul 22 2016 mpluskal@suse.com
- Disable support for ext2 - gh#mackyle/xar#10
* Sun Jan 31 2016 mpluskal@suse.com
- Tiny spec file cleanups
* Sat Apr 11 2015 p.drouand@gmail.com
- Update to version 1.6.1
  * Fix issues #75, #76
  * Added NEWS file
  * Stealth support for any available EVP_get_digestbyname hash (see man page)
  * Support digests sha224, sha256, sha384 and sha512 provided the linked
    libcrypto supports them (OpenSSL 0.9.8 and later).  Note that using a
  - -toc-cksum other than none, md5 or sha1 (the default) is NOT backwards
    compatible (requires extended binary header support), but using a
  - -file-cksum other than none, md5 or sha1 is backwards compatible provided
    the recipient's libcrypto supports it.  Both --toc-cksum and --file-cksum
    must be specified to get them to be different.
  * Do not attempt to extract attribute information to a non-file destination
  * Handle 6 more flags bits including UF_HIDDEN and UF_COMPRESSED
  * Fix xar_get_mode output to still include type when mode is unavailable
    (This also fixes alignment problems in -tv output when mode is missing)
  * Fix archival of FinderCreateTime on 64 bit archs (extract was already okay)
  * Add support for --recompress option to blindly recompress all files added
    to the archive not matched by a --no-compress option when a --compression
    type other than none is in effect.  All prior versions of xar always behave
    as though --recompress has been specified.
  * Recognized already-compressed files will now just be stored as-is in the
    archive without a second compression.  The gzip, bzip2 and xz formats are
    currently recognized.  The --recompress option disables this behavior.
    The xar library itself now provides this support (XAR_OPT_RECOMPRESS).
  * xar.h c++ compatibility added
  * XAR_OPT_TOCCKSUM can now be set after adding signatures without causing
    archive corruption
  * Update liblzma support to work with current liblzma versions
  * Show additional information in --version output if --verbose given first
  * Update man page and --help output to be current
  * Allow --compression=xz whenever --compression=lzma is supported
  * Now builds on cygwin
  * A huge number of warnings were eliminated so compilations should be much
    cleaner on many platforms now
  * Add support for --rfc6713 (see man page) (XAR_OPT_RFC6713FORMAT)
  * Support compiling against an older libcrypto but running against a newer one
  * Make extracted-checksum/archived-checksum use long hash name to match value
    used in toc checksum (backwards compatible)
  * Add missing trailing 'Z' to creation-date in archive (backwards compatible)
  * Help output (--help) now goes to standard output instead of standard error
  * Reduce spew on command line argument error
  * Support --directory (-C) during archive as well as extract
  * Add support for --to-stdout (-O) (XAR_OPT_EXTRACTSTDOUT)
  * Add support for --strip-components (XAR_OPT_STRIPCOMPONENTS)
  * Command aliases added (--create, --extract, --list, --file, --directory,
  - -verbose, --one-file-system, -V)
  * The xar header version can now be easily #if tested using XAR_VERSION_NUM
  * The xar library version can now be fetched with XAR_OPT_XARLIBVERSION
  * xar_from_base64 no longer adds extra bytes to the decoded output
  * Library now adds a signature-creation-time element which contains the
    "%%.1f" formatted number of seconds since 2001-01-01T00:00:00Z when any
    signatures are present
  * Rudimentary command line signature support (--sign/--replace-sign etc.)
  * configure now defaults compiler options to "-Wall -g -O2" for gcc
  * Update Xcode projects
  * Import into git (adding .gitignore and .gitattributes)
  * Initial release from https://github.com/mackyle/xar project
- Update project and download Urls
- Add autoconf build require; needed to generate the configure script
  from git
- Update documentation files list when process %%doc
* Mon Mar  2 2015 dimstar@opensuse.org
- Do not specify debug_package inside the .spec file: We control
  the generation of debuginfo packages by means of OBS flags.
* Fri Feb 27 2015 mpluskal@suse.com
- Call ldconfig in post and postun for library
* Tue Feb 24 2015 mpluskal@suse.com
- Cleanup spec-file with spec-cleaner
- Refresh dependecies
  * remove useless autotool, make and gcc
  * add libbz2-devel
* Sun Dec 30 2007 Pascal Bleser <guru@unixtech.be> 
- made libxar comply with the openSUSE Shared Library Packaging Policy
- update to 1.5.2
* Mon Aug 13 2007 Pascal Bleser <guru@unixtech.be>
- update to 1.5.1
* Thu May 31 2007 Pascal Bleser <guru@unixtech.be> 
- new package
